#
# spec file for package budgie-desktop
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013-2016 Ikey Doherty <ikey@solus-project.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
Name:           budgie-desktop
Version:        10.5.1+1ed6276b
Release:        lp152.8.1
Summary:        GTK3 Desktop Environment
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/GUI/Other
URL:            https://getsol.us/solus/experiences/
Source:         %{name}-%{version}.tar.xz
#Source1:        https://github.com/solus-project/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz.asc
#Source2:        %{name}.keyring
Source3:        budgie-desktop-nemo-autostart.desktop
# PATCH-FIX-OPENSUSE: Create a clean separation between Budgie and GNOME desktops
Patch:          desktop-override.patch
# PATCH-FIX-OPENSUSE: Use nemo instead of nautilus for desktop icons
Patch1:         nemo-instead-of-nautilus.patch
# PATCH-FIX-UPSTREAM gh#solus-project/budgie-desktop#2029
Patch2:         vala-0.49.patch
# PATCH-FIX-OPENSUSE Re-add Leap 15.2 support
Patch3:         Revert-GNOME-3.38-support.patch
BuildRequires:  intltool
BuildRequires:  meson >= 0.41.2
BuildRequires:  pkgconfig
BuildRequires:  sassc
BuildRequires:  pkgconfig(accountsservice)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(gnome-bluetooth-1.0)
BuildRequires:  pkgconfig(gnome-desktop-3.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(ibus-1.0)
BuildRequires:  pkgconfig(libgnome-menu-3.0)
BuildRequires:  pkgconfig(libpeas-gtk-1.0)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libwnck-3.0)
BuildRequires:  pkgconfig(polkit-agent-1)
BuildRequires:  pkgconfig(polkit-gobject-1)
BuildRequires:  pkgconfig(upower-glib)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(vapigen) >= 0.28
BuildRequires:  (pkgconfig(libmutter-5) or pkgconfig(libmutter-6) or pkgconfig(libmutter-7))
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(gnome-settings-daemon)
BuildRequires:  pkgconfig(alsa)
Requires:       typelib-1_0-PeasGtk-1_0
Requires:       typelib-1_0-Budgie-1_0
Requires:       ibus
Requires:       gnome-session-core
Requires:       gnome-settings-daemon
Requires:       gnome-control-center
Requires:       budgie-screensaver
Requires:       nemo
Recommends:     gnome-software
Recommends:     NetworkManager-applet
Recommends:     gnome-backgrounds
Recommends:     budgie-desktop-doc

%description
Budgie Desktop is the flagship desktop for the Solus Operating System.

%package -n typelib-1_0-Budgie-1_0
Summary:        Introspection bindings for the Budgie Desktop
Group:          System/Libraries 
Requires:       %{name} = %{version}-%{release}

%description -n typelib-1_0-Budgie-1_0
This package provides GObject Introspection files required for
developing Budgie Applets using interpreted languages, such as Python
GObject Introspection bindings.

%package devel
Summary:        Development files for the Budgie Desktop
Group:          Development/Libraries/GNOME
Requires:       %{name} = %{version}-%{release}
Requires:       typelib-1_0-Budgie-1_0 = %{version}-%{release}

%description devel
This package provides development files required for software to be
able to use and link against the Budgie APIs, to create their own
applets for the Budgie Panel.

%package doc
Summary:        Documentation files for the Budgie Desktop
Group:          Documentation/HTML

%description doc
This package provides API Documentation for the Budgie Plugin API, in the
GTK-Doc HTML format.

%package -n libraven0
Summary:        Shared library for Raven
Group:          System/Libraries

%description -n libraven0
Budgie Desktop Notification Center.

%package -n libbudgietheme0
Summary:        Shared library for Budgie theming
Group:          System/Libraries

%description -n libbudgietheme0
Budgie theming engine shared library package.

%package -n libbudgie-plugin0
Summary:        Shared library for Budgie plugins
Group:          System/Libraries

%description -n libbudgie-plugin0
Shared library for budgie plugins to link against.

%package -n libbudgie-private0
Summary:        Private library for Budgie
Group:          System/Libraries

%description -n libbudgie-private0
Private library for Budgie desktop to link against.

%lang_package

%prep
%setup -q
%patch -p1
%patch1 -p1
%patch2 -p1
if pkg-config --max-version 3.36 gnome-desktop-3.0; then
%patch3 -p1
fi

%build
%meson
%meson_build

%install
%meson_install

# update-alternatives
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/default-xsession.desktop
ln -s %{_sysconfdir}/alternatives/default-xsession.desktop %{buildroot}%{_datadir}/xsessions/default.desktop

# nemo autostart
cp %{SOURCE3} %{buildroot}%{_sysconfdir}/xdg/autostart

%find_lang %{name}

%post
%{_sbindir}/update-alternatives --install %{_datadir}/xsessions/default.desktop \
  default-xsession.desktop %{_datadir}/xsessions/budgie-desktop.desktop 20

%postun
[ -f %{_datadir}/xsessions/budgie-desktop.desktop ] || %{_sbindir}/update-alternatives \
  --remove default-xsession.desktop %{_datadir}/xsessions/budgie-desktop.desktop

%post   -n libraven0 -p /sbin/ldconfig
%postun -n libraven0 -p /sbin/ldconfig
%post   -n libbudgietheme0 -p /sbin/ldconfig
%postun -n libbudgietheme0 -p /sbin/ldconfig
%post   -n libbudgie-plugin0 -p /sbin/ldconfig
%postun -n libbudgie-plugin0 -p /sbin/ldconfig
%post   -n libbudgie-private0 -p /sbin/ldconfig
%postun -n libbudgie-private0 -p /sbin/ldconfig

%files
%license LICENSE LICENSE.LGPL2.1
%{_datadir}/gnome-session
%{_bindir}/budgie-*
%{_datadir}/applications/budgie-*.desktop
%{_datadir}/glib-2.0/schemas/com.solus-project.*.gschema.xml
%{_datadir}/glib-2.0/schemas/20_solus-project.budgie.wm.gschema.override
%{_datadir}/icons/hicolor/scalable/*/*.svg
%{_datadir}/xsessions/default.desktop
%{_datadir}/xsessions/budgie-desktop.desktop
%{_libdir}/budgie-desktop
%{_sysconfdir}/xdg/autostart/budgie-desktop-screensaver.desktop
%{_sysconfdir}/xdg/autostart/budgie-desktop-nm-applet.desktop
%{_sysconfdir}/xdg/autostart/budgie-desktop-nemo-autostart.desktop
%ghost %{_sysconfdir}/alternatives/default-xsession.desktop

%files -n libraven0
%{_libdir}/libraven.so.*

%files -n libbudgietheme0
%{_libdir}/libbudgietheme.so.*

%files -n libbudgie-plugin0
%{_libdir}/libbudgie-plugin.so.*

%files -n libbudgie-private0
%{_libdir}/libbudgie-private.so.*

%files devel
%{_includedir}/budgie-desktop
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so
%{_datadir}/gir-1.0/Budgie-1.0.gir
%{_datadir}/vala/vapi/budgie-1.0.*

%files -n typelib-1_0-Budgie-1_0
%{_libdir}/girepository-1.0/Budgie-1.0.typelib

%files doc
%{_datadir}/gtk-doc/html/budgie-desktop

%files lang -f %{name}.lang

%changelog
* Mon Dec 21 2020 Callum Farmer <gmbr3@opensuse.org>
- Leap 15.3 fixes
* Sat Sep 19 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Use a better format for testing gnome versions
* Sun Sep 13 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add budgie-desktop-branding to Recommends
* Sat Sep 12 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add patch Revert-GNOME-3.38-support.patch: Leap 15.2 only
- Updated BuildRequires:
  * pkgconfig(libmutter-6/7) >> pkgconfig(libmutter-5/6/7)
* Thu Sep 10 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Revert vala path changes
* Thu Sep 10 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add patch vala-0.49.patch: fixes build with vala 0.49
  (gh#solus-project/budgie-desktop#2029)
* Wed Sep  9 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to git version 10.5.1+1ed6276b:
  * Prevents keeping a load of patches, 10.5.2 might be ages away
  * Added support for GNOME 3.38
  * Removed support for GNOME 3.34 and below
- Removed patches:
  * support-libmutter6.patch
  * Rework-grab-and-ungrab-keys.patch
  * mutter-3-35-91.patch
  * gnome-coexistance.patch
  * replace-na-tray-with-carbontray.patch
  * clean-up-carbontray.patch
  * fix-integration-issues-with-carbontray.patch
- Updated BuildRequires:
  * pkgconfig(libmutter-5/6) >> pkgconfig(libmutter-6/7)
* Sat Sep  5 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add patches to fix boo#1176016:
  * replace-na-tray-with-carbontray.patch
    (gh#solus-project/budgie-desktop#1998)
  * clean-up-carbontray.patch
    (gh#solus-project/budgie-desktop#2002)
  * fix-integration-issues-with-carbontray.patch
    (gh#solus-project/budgie-desktop#2009)
* Mon Aug 31 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add nemo-instead-of-nautilus.patch: Nautilus doesn't have support
  for desktop icons anymore
- Add nemo to Requires for desktop icons
* Sat Aug 29 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add desktop-override.patch from Debian: fixes overlap between
  Budgie and GNOME in gschema
* Sat Aug 29 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add budgie-screensaver to Requires
- Change gnome-software from Requires to Recommends:
  * Asked for by S. B. <sb56637@gmail.com>
* Thu Aug 13 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Change gnome-control-center from Recommends to Requires:
  * Needed for changing desktop background
- Add gnome-software to Requires:
  * Needed for links in gnome-control-center
* Wed Aug 12 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add gnome-session-core as a dependency
- Spec file cleanups
- Correct URL
* Tue Aug 11 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Remove gnome-session dependency
* Mon Aug 10 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fix desktop icons
* Mon Aug 10 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add patches:
  * Rework-grab-and-ungrab-keys.patch (gh#solus-project/budgie-desktop#1907)
  * mutter-3-35-91.patch (gh#solus-project/budgie-desktop#1939)
  * gnome-coexistance.patch (gh#solus-project/budgie-desktop#1984)
- Remove old %%post and %%postun
- Add new Requires:
  * ibus
  * typelib-1_0-PeasGtk-1_0
  * typelib-1_0-Budgie-1_0
* Mon Aug 10 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add xsession update-alternatives
* Sun Aug  9 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Rename and recommend doc package
* Sun Aug  9 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Create separate lang package
* Sat Aug  8 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Move vala to correct directory
- Correct typelib library name
- Removed fix-meson-build.patch: contained in upstream
- Removed support-libmutter2.patch: contained in upstream
- Added support-libmutter6.patch: adds support for mutter 3.36
- Correct license name
- Switch to verified sources:
  * Add source.asc and GPG keyring
- Add new BuildRequires:
  * pkgconfig(libnotify)
  * pkgconfig(gnome-settings-daemon)
  * pkgconfig(alsa)
- Updated BuildRequires:
  * pkgconfig(libmutter-2) >> pkgconfig(libmutter-6)
- Add new library libbudgie-private0
- Update to version 10.5.1:
  * For the changes see
    https://getsol.us/2019/10/03/budgie-and-its-army-of-gnomes/
* Sun Apr 15 2018 matthias.eliasson@gmail.com
- Add support-libmutter2.patch: This to support the version of
  mutter in openSUSE:Factory.
- Change copyright year to 2018
- Change licenses to SPDX-3.0 version
- Modernize spec-file with spec-cleaner
* Thu Nov 30 2017 qantas94heavy@gmail.com
- Add fix-meson-build.patch: fixes gvc subproject sandbox issue
  with Meson 0.43.0
* Mon Sep 18 2017 mailaender@opensuse.org
- Update pkgconfig libmutter-0 to libmutter-1
* Sun Aug 20 2017 mailaender@opensuse.org
- Drop sed fix bdugie-desktop typo (resolved upstream)
* Tue Aug 15 2017 mailaender@opensuse.org
- Update to version 10.4 "Irish Summer"
- Drop upstream gtk-3.22.14+raven-crash-fix.patch
- Drop upstream meson-0.41.patch
- Drop upstream 0001-wm-Default-to-an-empty-rpath.patch
* Mon Jul 24 2017 matcherapy@gmail.com
- fix empty rpath 0001-wm-Default-to-an-empty-rpath.patch
* Sat Jul 22 2017 mailaender@opensuse.org
- Fix build with meson 0.41 using meson-0.41.patch
* Tue Jun 13 2017 jengelh@inai.de
- Redo descriptions.
* Sun Jun  4 2017 mailaender@opensuse.org
- Add gtk-3.22.14+raven-crash-fix.patch to fix #918
* Fri Apr 21 2017 dev+novell@devmotion.de
- Update to v10.3.1
- See https://github.com/budgie-desktop/budgie-desktop/releases/tag/v10.3.1
* Fri Jan 27 2017 mailaender@opensuse.org
- Add https://en.opensuse.org/SourceUrls
- Fix standard-dir-owned-by-package rpmlint warnings
- Implement shared library policy
* Fri Dec 16 2016 ikey.doherty@gmail.com
- Update to v10.2.9 - a maintenance release
- See: https://github.com/budgie-desktop/budgie-desktop/releases/tag/v10.2.9
* Wed Nov  9 2016 sfalken@opensuse.org
- Fixed /usr/bin ownership conflict for F24
* Sat Nov  5 2016 sfalken@opensuse.org
- Added docbook2X buildrequire for Fedora, builds for F24 now
* Sat Nov  5 2016 sfalken@opensuse.org
- Added conditional BuildDeps for Fedora
* Sat Nov  5 2016 sfalken@opensuse.org
- Did some spec cleanup, for maintainability and clarity
* Sat Oct 29 2016 ikey.doherty@gmail.com
- Yet another Fedora change. Strongly considering dropping support for them.
* Sat Oct 29 2016 ikey.doherty@gmail.com
- Explicitly require gtk-doc for Fedora.
* Sat Oct 29 2016 ikey.doherty@gmail.com
- Fix even more build failures with ancient Vala. Circa 1940.
* Sat Oct 29 2016 ikey.doherty@gmail.com
- Reflow patch series specifically to this OBS repo
- Fix build failures on Fedora 22, 23, and openSUSE Leap 42.1 by
  allowing old ibus versions and removing use of Source.REMOVE which
  is unavailable in their vala versions.
* Sat Oct 29 2016 ikey.doherty@gmail.com
- Update to Budgie Desktop 10.2.8
- Sync some essential patches for an enhanced experience
* Thu Jul 28 2016 ikey.doherty@gmail.com
- Remove the screensaver component for now
* Mon Jul 11 2016 ikey.doherty@gmail.com
- Update to v10.2.6
  - https://github.com/solus-project/budgie-desktop/releases/tag/v10.2.6
* Sun Mar 27 2016 ikey.doherty@gmail.com
- Fix version number in documentation - we didn't update it in this
  point release
* Sun Mar 27 2016 ikey.doherty@gmail.com
- Update to v10.2.5, and exclude .la files
* Sun Feb 28 2016 ikey.doherty@gmail.com
- Account for html files too
* Sun Feb 28 2016 ikey.doherty@gmail.com
- Fix noobish packaging issues
* Sun Feb 28 2016 ikey.doherty@gmail.com
- Add -docs subpackage
* Sun Feb 28 2016 ikey.doherty@gmail.com
- Update to 10.2.4
* Sun Jan  3 2016 ikey.doherty@gmail.com
- Fix many linking/portability issues on other distributions
- Fix nm-applet-likes-small-holes bug (size of x11 tray icons)
- Respect and follow screen resolution changes
- Fix background corruption on resume with NVIDIA gpus
- Fix use of colours for backgrounds
- Replace polkit-gnome dependency with our own new budgie-polkit
- Refactor much of the codebase into smallerl ibraries
- Updated translations
- Fix bug #166 (firefox becomes homeless)
- Fix uhm-is-that-youtube-i-see-through-gedit-thar transparency issue
- Consumed several pizzas
* Wed Dec 30 2015 ikey.doherty@gmail.com
- Use find_lang due to borked directory ownership
* Wed Dec 30 2015 ikey.doherty@gmail.com
- Drop requirements down to GNOME 3.16 stack for openSUSE Leap 42 users
- Introduce many translations
- Fix derpiness of panel when using Raven (moving screen edge)
- Partially fix mumble notifications (more to happen here yet)
- Use unique desktop name (XDG_CURRENT_DESKTOP=Budgie:GNOME)
- Ship our own nm-applet .desktop launcher until we have our own network settings
- Go back to "view-grid-symbolic" icon
* Mon Dec 28 2015 ikey.doherty@gmail.com
- Drop gnome-control-center dependency, causing issues on Fedora
- Apply some patches to enable building on 3.16 GNOME stack (from git)
* Mon Dec 28 2015 ikey.doherty@gmail.com
- Initial packaging for openSUSE:Factory and Fedora 23
